@@ -268,6 +268,19 @@ class TestPropertyRelation:
         with pytest.raises(AttributeError):
             relation.type = "new_type"
 
+    def test_property_relation_target_types(self):
+        """Test PropertyRelation with targetTypes."""
+        relation = PropertyRelation(
+            type="friendship", targetTypes=["person", "organization"]
+        )
+        assert relation.targetTypes == ["person", "organization"]
+        assert relation.target is None
+
+    def test_property_relation_no_object_type(self):
+        """Test PropertyRelation does not accept objectType."""
+        with pytest.raises(TypeError):
+            PropertyRelation(objectType="person")
+
 
 class TestMonitorConfig:
     """Test MonitorConfig dataclass."""
